@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      https://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,13 +30,14 @@ import org.apache.commons.lang3.StringUtils;
  * Each method documents its behavior in more detail.</p>
  *
  * @since 2.0
- * @deprecated As of <a href="https://commons.apache.org/proper/commons-lang/changes-report.html#a3.6">3.6</a>, use Apache Commons Text
+ * @deprecated As of 3.6, use Apache Commons Text
  * <a href="https://commons.apache.org/proper/commons-text/javadocs/api-release/org/apache/commons/text/WordUtils.html">
- * WordUtils</a>.
+ * WordUtils</a> instead
  */
 @Deprecated
 public class WordUtils {
 
+    // Capitalizing
     /**
      * Capitalizes all the whitespace separated words in a String.
      * Only the first character of each word is changed. To convert the
@@ -272,11 +273,11 @@ public class WordUtils {
             final char ch = str.charAt(i);
             if (isDelimiter(ch, delimiters)) {
                 lastWasGap = true;
-                continue;  // ignore ch
-            }
-            if (lastWasGap) {
+            } else if (lastWasGap) {
                 buf[count++] = ch;
                 lastWasGap = false;
+            } else {
+                continue; // ignore ch
             }
         }
         return new String(buf, 0, count);
